==> migrate_wizard-1.0.19-alpha1.tar.gz: migrate_wizard/src/Form/OriginParagraphsFields.php <==
<?php

namespace Drupal\migrate_wizard\Form;

use Drupal\Core\Config\ConfigFactoryInterface;
use Drupal\Core\Entity\EntityFieldManagerInterface;
use Drupal\Core\Entity\EntityTypeManagerInterface;
use Drupal\Core\Form\FormStateInterface;
use Drupal\migrate_wizard\MWConfigBuilder;
use Drupal\migrate_wizard\MWManageDataService;
use Symfony\Component\DependencyInjection\ContainerInterface;

/**
 * Configure migrate_wizard.
 */
class OriginParagraphsFields extends BaseFormFields {

  use BaseFormFieldsTrait;

  /**
   * {@inheritdoc}
   */
  public function getFormId() {
    return 'manage_origin_paragraph_fields';
  }

  /**
   * {@inheritdoc}
   */
  public function buildForm(array $form, FormStateInterface $form_state, string $origin_bundle = NULL) {
    $this->originType = 'paragraphs_item';
    $this->fieldsOriginBundle = $this->manageFormService->getFieldsOriginBundle($this->originBundle, $this->originType);
    $this->manageFormService->setFieldsOriginBundle($this->fieldsOriginBundle);
    $this->destinyType = 'paragraph';

    $form['origin_type'] = [
      '#type' => 'hidden',
      '#value' => 'paragraph_item',
    ];

    $this->langCodes['default_lang']['value'] = $this->mwManageDataService->getOriginDefaultLangcode();

    $config_translation = $this->mwManageDataService->getOriginLanguages($form["origin_type"]["#value"], $origin_bundle);

    foreach($config_translation["origin_languages"] as $language){
      $this->langCodes[$language.'_lang'] = [
        'markup' => $language,
        'value' => $language,
      ];
    }

    return parent::buildForm($form, $form_state, $origin_bundle);
  }
  public function getTitle($type = null): \Drupal\Core\StringTranslation\TranslatableMarkup
  {
    $current_path = \Drupal::service('path.current')->getPath();
    $path = explode('/', $current_path);
    $path = end($path);
    return $this->t('Manage fields '.$path);
  }
}

==> migrate_wizard-2.0.2-alpha1.tar.gz: migrate_wizard/src/Form/OriginParagraphsFields.php <==
<?php

namespace Drupal\migrate_wizard\Form;

use Drupal\Core\Config\ConfigFactoryInterface;
use Drupal\Core\Entity\EntityFieldManagerInterface;
use Drupal\Core\Entity\EntityTypeManagerInterface;
use Drupal\Core\Form\FormStateInterface;
use Drupal\migrate_wizard\MWConfigBuilder;
use Drupal\migrate_wizard\MWManageDataService;
use Symfony\Component\DependencyInjection\ContainerInterface;

/**
 * Configure migrate_wizard.
 */
class OriginParagraphsFields extends BaseFormFields {

  use BaseFormFieldsTrait;

  /**
   * {@inheritdoc}
   */
  public function getFormId() {
    return 'manage_origin_paragraph_fields';
  }

  /**
   * {@inheritdoc}
   */
  public function buildForm(array $form, FormStateInterface $form_state, $origin_bundle = NULL) {
    $this->originType = 'paragraphs_item';
    $this->fieldsOriginBundle = $this->manageFormService->getFieldsOriginBundle($this->originBundle, $this->originType);
    $this->manageFormService->setFieldsOriginBundle($this->fieldsOriginBundle);
    $this->destinyType = 'paragraph';

    $form['origin_type'] = [
      '#type' => 'hidden',
      '#value' => 'paragraph_item',
    ];

    $this->langCodes['default_lang']['value'] = $this->mwManageDataService->getOriginDefaultLangcode();

    $config_translation = $this->mwManageDataService->getOriginLanguages($form["origin_type"]["#value"], $origin_bundle);

    foreach($config_translation["origin_languages"] as $language){
      $this->langCodes[$language.'_lang'] = [
        'markup' => $language,
        'value' => $language,
      ];
    }

    return parent::buildForm($form, $form_state, $origin_bundle);
  }
  public function getTitle($type = null): \Drupal\Core\StringTranslation\TranslatableMarkup
  {
    $current_path = \Drupal::service('path.current')->getPath();
    $path = explode('/', $current_path);
    $path = end($path);
    return $this->t('Manage fields '.$path);
  }
}
